unittest.TextTestRunner

unittest :: TextTestRunner :: Class TextTestRunner |
[hide private]
[frames] | no frames]

# Class TextTestRunner

source code

    object --+
             |
            TextTestRunner

A test runner class that displays results in textual form.

It prints out the names of tests as they are run, errors as they occur, and a summary of the results at the end of the test run.

Instance Methods | [hide private]
__init__(self, stream=<epydoc.docintrospecter._DevNull instance at 0xaf12d8>, descriptions=1, verbosity=1) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
_makeResult(self) | source code
run(self, test) Run the given test case or test suite. | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, stream=<epydoc.docintrospecter._DevNull instance at 0xaf12d8>, descriptions=1, verbosity=1) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)